@@ -5,7 +5,9 @@ import sys
 import textwrap
 import optparse
 
-from utils import get_terminal_size
+from rider.cli import cmdoptions
+from rider.cli.utils import get_terminal_size
+from rider import __version__
 
 
 class PrettyHelpFormatter(optparse.IndentedHelpFormatter):
@@ -148,4 +150,42 @@ class ConfigOptionParser(CustomOptionParser):
 
     def error(self, msg):
         self.print_usage(sys.stderr)
-        self.exit(2, "%s\n" % msg)
\ No newline at end of file
+        self.exit(2, "%s\n" % msg)
+
+
+def create_parser(command_summaries, parser_kw, general_group=cmdoptions.general_group):
+    parser = ConfigOptionParser(**parser_kw)
+    parser.disable_interspersed_args()
+
+    # add the general options
+    gen_opts = cmdoptions.make_option_group(general_group, parser)
+    parser.add_option_group(gen_opts)
+
+    # create command listing for description
+    description = [''] + ['%-27s %s' % (i, j) for i, j in command_summaries]
+    parser.description = '\n'.join(description)
+    parser.main = True  # so the help formatter knows
+
+    return parser
+
+
+def parse_opts(args, command_summaries, parser_kw, general_group):
+    main_parser = create_parser(command_summaries, parser_kw, general_group)
+
+    # first get the general options
+    general_options, args_else = main_parser.parse_args(args)
+
+    if general_options.version:
+        sys.stdout.write("version {}\n".format(__version__))
+        sys.exit()
+
+    if not args_else or (args_else[0].lower() == 'help' and len(args_else) == 1):
+        main_parser.print_help()
+        sys.exit()
+
+    # the subcommand name
+    cmd_name = args_else[0].lower()
+    # all the args without the subcommand
+    cmd_args = args[:]
+    cmd_args.remove(args_else[0].lower())
+    return cmd_name, cmd_args
\ No newline at end of file
