@@ -29,13 +29,13 @@ class Service(object):
 
     def _can_be_scaled(self):
 
-        if self._service.name == 'master' or self._service.name == 'dsh':
+        if self._service.name == 'master' or self._service.name == 'multimaster':
             raise CouldNotScale(self._service.name)
         else:
             return True
 
     def is_scaleable(self):
-        if self._service.name == 'master' or self._service.name == 'dsh':
+        if self._service.name == 'master' or self._service.name == 'multimaster':
             return False
         else:
             return True
